chunky.chunkers
===============

.. automodule:: chunky.chunkers

   
.. rubric:: Modules

.. autosummary::
   :toctree:
   :recursive:

   fallback
   fortran
   markdown
   notebook
   python
   rst
   text
   treesitter
   yaml_json
